Settings — Django Kamasutra v0.2.2 documentation

Django Kamasutra v0.2.2 documentation

# Settings

- Table of Contents
- index
  next
  previous

# Settings

Below is a list of all the position settings

## POSITION_CONTENT_OVERLAP_COUNT

The number of objects to keep after the position has added more items then its position.count specified.

Default - 2.

## POSITION_COMBINE_STRING

A url safe string used to combine position name prefix and suffix. This is also used to build template paths.

Default - __ (2 under scores)